<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WC_Featured_Listing_Frontend' ) ) :

	/**
	 * WC_Featured_Listing_Frontend.
	 *
	 * Frontend Event Handler.
	 *
	 * @class    WC_Featured_Listing_Frontend
	 * @package  WC_Featured_Listing/Classes
	 * @author   itzmekhokan
	 */
	class WC_Featured_Listing_Frontend {

		/**
		 * Constructor for the frontend class. Hooks in methods.
		 */
		public function __construct() {
			add_action( 'woocommerce_shop_loop_item_title', array( $this, 'wcfl_add_featured_label_tags' ), 20 );
			add_action( 'woocommerce_before_single_product_summary', array( $this, 'wcfl_add_featured_label_tags' ), 10 );
			add_filter( 'wcfl_is_enabled_featured_products', array( $this, 'wcfl_is_enabled_featured_products' ), 10, 2 );
		}

		public function wcfl_add_featured_label_tags() {
			global $product;
			if ( ! $product->is_featured() ) {
				return;
			}
			echo '<span class="wcfl-feature onsale">' . esc_html( apply_filters( 'wcfl_featured_label_tags_html', __( 'Featured!', 'woocommerce' ), $product ) ) . '</span>';
		}

		public function wcfl_is_enabled_featured_products( $flag, $query ) {
			if ( ! isset( $query->query_vars['wc_query'] ) ) {
				$flag = false; // if query not related to product
			}
			if ( ! wcfl_global_featured_listing_enabled() ) {
				if ( isset( $query->is_post_type_archive ) && $query->is_post_type_archive && wcfl_shop_featured_listing_enabled() ) {
					$flag = true;
				}
				if ( isset( $query->is_archive ) && $query->is_archive && isset( $query->is_tax ) && $query->is_tax && wcfl_taxonomy_featured_listing_enabled() ) {
					$flag = true;
				}
				if ( isset( $query->query['s'] ) && isset( $query->is_search ) && $query->is_search && wcfl_search_featured_listing_enabled() ) {
					$flag = true;
				}
			} else {
				$flag = true;
			}
			return $flag;
		}

	}

	endif; // class_exists

return new WC_Featured_Listing_Frontend();
